#[derive(EvenframeUnion)]
{
// Attributes available to this derive:
#[macroforge_derive]
#[annotation]
}
Derive macro for unions of persistable structs Each variant must contain exactly one persistable struct type
#[derive(EvenframeUnion)]
{
// Attributes available to this derive:
#[macroforge_derive]
#[annotation]
}
Derive macro for unions of persistable structs Each variant must contain exactly one persistable struct type